## Description

<!-- Describe your changes in detail -->

## Type of Change

- [ ] 🐛 Bug fix (non-breaking change fixing an issue)
- [ ] ✨ New feature (non-breaking change adding functionality)
- [ ] 💥 Breaking change (fix or feature causing existing functionality to change)
- [ ] 📚 Documentation update
- [ ] 🔧 Refactoring (no functional changes)
- [ ] 🧪 Test update

## Related Issues

<!-- Link any related issues using "Fixes #123" or "Closes #123" -->

Fixes #

## Checklist

- [ ] My code follows the project's code style
- [ ] I have run `ruff check .` and fixed any issues
- [ ] I have run `mypy contextguard` with no errors
- [ ] I have run `pytest` and all tests pass
- [ ] I have added tests for new functionality
- [ ] I have updated documentation if needed
- [ ] My commits follow the [Conventional Commits](https://www.conventionalcommits.org/) format

## Screenshots / Trace Output

<!-- If applicable, add screenshots or trace DAG outputs to demonstrate your changes -->
